==> f_k_chart-1.0.1.tar.gz: lib/view/kline_view.dart <==
import 'package:f_k_chart/model/kline_data.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:f_k_chart/bloc/kline_bloc.dart';
import 'package:f_k_chart/common/bloc_provider.dart';
import 'package:f_k_chart/model/kline_model.dart';
import 'package:f_k_chart/view/kline_single_view.dart';

class KlinePage extends StatefulWidget {
  KlinePage(
    this.datas, {
    Key key,
//    @required this.bloc
  }) : super(key: key);

  List<KlineData> datas;

  @override
  State<StatefulWidget> createState() {
    // TODO: implement createState
    return _KlinePageState();
  }
}

class _KlinePageState extends State<KlinePage> {
  KlineBloc bloc;

  @override
  void initState() {
    super.initState();
    bloc = KlinePageBloc();
  }

  @override
  void didUpdateWidget(KlinePage oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.datas != widget.datas) {
      bloc.updateDataList(widget.datas);
//      bloc.openRealTime(true);
    }
  }

  @override
  void dispose() {
    bloc?.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    Offset lastPoint;
    int offset;
    double lastScale;
    int count;
    double currentRectWidth;
    bool isScale = false;

    ScrollController _controller = ScrollController(
        initialScrollOffset:
            bloc.rectWidth * bloc.stringList.length - bloc.screenWidth);
    _controller.addListener(() {
//      print('print_offset:' + _controller.offset.toString()); //打印滚动位置

//      if (bloc.stringList != null && bloc.stringList.length >0) {
        int currentIndex = (_controller.offset ~/ bloc.rectWidth).toInt() + 1;
        if (currentIndex < 0) {
          return;
        } else if (currentIndex > bloc.stringList.length - count) {
          return;
        }
        bloc.currentIndex = currentIndex;
        bloc.getSubKlineList(currentIndex, currentIndex + count);
//      }
    });

    return BlocProvider<KlineBloc>(
        //key: PageStorageKey('market'),
        bloc: bloc,
        child: GestureDetector(
            onScaleStart: (details) {
              currentRectWidth = bloc.rectWidth;
              isScale = true;
            },
            onScaleUpdate: (details) {
              double scale = details.scale;
              if (scale == 1.0) {
                return;
              }
              print("print_scale:" + details.scale.toString());
              lastScale = details.scale;
              double rectWidth = scale * currentRectWidth;
              count = (MediaQuery.of(context).size.width ~/ bloc.rectWidth)
                      .toInt() +
                  1;
              bloc.setRectWidth(rectWidth);
              bloc.getSubKlineList(
                  bloc.currentIndex, bloc.currentIndex + count);
            },
            onScaleEnd: (details) {
              isScale = false;
            },
            child: StreamBuilder(
                stream: bloc.outklineList,
                builder: (BuildContext context,
                    AsyncSnapshot<List<Market>> snapshot) {
                  List<Market> data = snapshot.data;
                  if (data != null) {
                    double width = MediaQuery.of(context).size.width;
                    count = (width ~/ bloc.rectWidth).toInt() + 1;
                    bloc.setScreenWith(width);
                    // _controller.jumpTo(bloc.rectWidth * bloc.stringList.length-bloc.screenWidth);
                  }
                  return Container(
                    child: Stack(
                      alignment: Alignment.center,
                      fit: StackFit.expand,
                      children: <Widget>[
                        Column(
                          children: <Widget>[
                            Expanded(
                              child: Container(
                                color: Colors.black,
                                child: KlineSingleView(type: 0),
                              ),
                              flex: 20,
                            ),
                            Expanded(
                              child: Container(
                                color: Colors.black,
                                child: KlineSingleView(type: 1),
                              ),
                              flex: 4,
                            ),
                          ],
                        ),
                        Scrollbar(
                            child: SingleChildScrollView(
                          child: Container(
                            width: (bloc.rectWidth * data?.length ?? 0).toDouble(),
                          ),
                          controller: _controller,
                          scrollDirection: Axis.horizontal,
                        )),
                      ],
                    ),
                  );
                })));
  }
}

class KlinePageBloc extends KlineBloc {
  @override
  //重写init方法
  void initData() {
//    Future<String> future = loadAsset();
//    future.then((value) {
//      final parseJson = json.decode(value);
//      MarketData marketData = MarketData.fromJson(parseJson);
//      List<KlineData> list = List<KlineData>();
//      for (var item in marketData.data) {
//        list.add(KlineData(
//            open: item.open,
//            close: item.close,
//            high: item.high,
//            low: item.low,
//            vol: item.amount,
//            date: item.date));
//      }
//      //数据返回后调用 updateDataList(list);
//      this.updateDataList(list);
//    });
    this.updateDataList([]);
    super.initData();
  }
}

==> f_k_chart-1.1.0.tar.gz: lib/view/kline_view.dart <==
import 'package:f_k_chart/model/kline_data.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:f_k_chart/bloc/kline_bloc.dart';
import 'package:f_k_chart/common/bloc_provider.dart';
import 'package:f_k_chart/model/kline_model.dart';
import 'package:f_k_chart/view/kline_single_view.dart';

class KlinePage extends StatefulWidget {
  KlinePage(
    this.datas, {
    Key key,
//    @required this.bloc
  }) : super(key: key);

  List<KlineData> datas;

  @override
  State<StatefulWidget> createState() {
    // TODO: implement createState
    return _KlinePageState();
  }
}

class _KlinePageState extends State<KlinePage> {
  KlineBloc bloc;

  @override
  void initState() {
    super.initState();
    bloc = KlinePageBloc();
  }

  @override
  void didUpdateWidget(KlinePage oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.datas != widget.datas) {
      bloc.updateDataList(widget.datas);
//      bloc.openRealTime(true);
    }
  }

  @override
  void dispose() {
    bloc?.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    Offset lastPoint;
    int offset;
    double lastScale;
    int count;
    double currentRectWidth;
    bool isScale = false;

    ScrollController _controller = ScrollController(
        initialScrollOffset:
            bloc.rectWidth * bloc.stringList.length - bloc.screenWidth);
    _controller.addListener(() {
//      print('print_offset:' + _controller.offset.toString()); //打印滚动位置

//      if (bloc.stringList != null && bloc.stringList.length >0) {
        int currentIndex = (_controller.offset ~/ bloc.rectWidth).toInt() + 1;
        if (currentIndex < 0) {
          return;
        } else if (currentIndex > bloc.stringList.length - count) {
          return;
        }
        bloc.currentIndex = currentIndex;
        bloc.getSubKlineList(currentIndex, currentIndex + count);
//      }
    });

    return BlocProvider<KlineBloc>(
        //key: PageStorageKey('market'),
        bloc: bloc,
        child: GestureDetector(
            onScaleStart: (details) {
              currentRectWidth = bloc.rectWidth;
              isScale = true;
            },
            onScaleUpdate: (details) {
              double scale = details.scale;
              if (scale == 1.0) {
                return;
              }
              lastScale = details.scale;
              double rectWidth = scale * currentRectWidth;
              count = ((MediaQuery.of(context).size.width-123.0) ~/ bloc.rectWidth)
                      .toInt() +
                  1;
              bloc.setRectWidth(rectWidth);
              bloc.getSubKlineList(
                  bloc.currentIndex, bloc.currentIndex + count);
            },
            onScaleEnd: (details) {
              isScale = false;
            },
            child: StreamBuilder(
                stream: bloc.outklineList,
                builder: (BuildContext context,
                    AsyncSnapshot<List<Market>> snapshot) {
                  List<Market> data = snapshot.data;
                  if (data != null) {
                    double width = MediaQuery.of(context).size.width-123.0;
                    count = (width ~/ bloc.rectWidth).toInt() + 1;
                    bloc.setScreenWith(width);
                    // _controller.jumpTo(bloc.rectWidth * bloc.stringList.length-bloc.screenWidth);
                  }
                  return Container(
                    child: Stack(
                      alignment: Alignment.center,
                      fit: StackFit.expand,
                      children: <Widget>[
                        Column(
                          children: <Widget>[
                            Expanded(
                              child: Container(
                                color: Colors.black,
                                child: KlineSingleView(type: 0),
                              ),
                              flex: 20,
                            ),
                            Expanded(
                              child: Container(
                                color: Colors.black,
                                child: KlineSingleView(type: 1),
                              ),
                              flex: 4,
                            ),
                          ],
                        ),
                        Scrollbar(
                            child: SingleChildScrollView(
                          child: Container(
                            width: (bloc.rectWidth * data?.length ?? 0).toDouble(),
                          ),
                          controller: _controller,
                          scrollDirection: Axis.horizontal,
                        )),
                      ],
                    ),
                  );
                })));
  }
}

class KlinePageBloc extends KlineBloc {
  @override
  //重写init方法
  void initData() {
//    Future<String> future = loadAsset();
//    future.then((value) {
//      final parseJson = json.decode(value);
//      MarketData marketData = MarketData.fromJson(parseJson);
//      List<KlineData> list = List<KlineData>();
//      for (var item in marketData.data) {
//        list.add(KlineData(
//            open: item.open,
//            close: item.close,
//            high: item.high,
//            low: item.low,
//            vol: item.amount,
//            date: item.date));
//      }
//      //数据返回后调用 updateDataList(list);
//      this.updateDataList(list);
//    });
    this.updateDataList([]);
    super.initData();
  }
}
